<?php

namespace App\JsonRpc;

use App\Model\Link;
use Hyperf\RpcServer\Annotation\RpcService;
use App\Tools\Result;


#[RpcService(name: "LinkService", protocol: "jsonrpc-http", server: "jsonrpc-http")]
class LinkService implements LinkServiceInterface
{
    /**
     * @param array $data
     * @return array
     */
    public function getLinkList(array $data): array
    {
        // return Result::success($data);
        $where = [];
        if(isset($data['title']) && !empty($data['title'])){
            array_push($where,['link.title','like','%'.$data['title'].'%']);
        }
        if(isset($data['website_id']) && !empty($data['website_id'])){
            array_push($where,['link.website_id','=',$data['website_id']]);
        }
        $result  = [];
        // return Result::success($where);
        if(!empty($where)){
            $query = Link::where($where);
            $count = $query->count();
        }else{
            $query = Link::query();
            $count = $query->count();
        }
// 重新构建查询，避免 $query 已经被修改

$rep = $query
    ->leftJoin("website", "website.id", "link.website_id")
    ->select("link.*", "website.website_name")
    ->limit($data['pageSize'])->offset(($data['page'] - 1) * $data['pageSize'])
    ->orderBy("sort", "asc")
    ->get();
// $countQuery = clone $query;
// $count = $countQuery->count();
        $result = [
            'rows'=>$rep,
            'count'=>$count
        ];
        if(empty($result)){
            return Result::error("没有查到数据");
        }
        return $result?Result::success($result):Result::error("没有查到数据");
    }

    /**
     * @param array $data
     * @return array
     */
    public function createLink(array $data): array
    {


        $result = Link::insertGetId($data);
        if (empty($result)) {
            return Result::error("创建失败", 0);
        } else {
            return Result::success(["id" => $result]);
        }
    }

    /**
     * @param array $data
     * @return array
     */
    public function updateLink(array $data): array
    {
        //website_name` = '三农市场网', `status_name` =
        unset($data['website_name']);
        unset($data['status_name']);
        $result = Link::where('id', $data['id'])->update($data);
        if (empty($result)) {
            return Result::error("更新失败", 0);
        } else {
            return Result::success();
        }
    }

    /**
     * @param array $data
     * @return array
     */
    public function delLink(array $data): array
    {
        // return Result::success($data);
        $result = Link::where('id', $data['id'])->delete();
        // return Result::success($result);
        // var_dump($result);
        if (empty($result)) {
            return Result::error("删除失败", 0);
        } else {
            return Result::success($result);
        }
    }

    /**
     * 获取友情链接详情
     * @param array $data
     * @return array
     */
    public function getLinkInfo(array $data): array
    {
        $result = Link::where('id', $data['id'])->first();
        if (empty($result)) {
            return Result::error("获取友情链接详情失败", 0);
        } else {
            return Result::success($result);
        }
    }

}